@@ -10,26 +10,31 @@ pub fn get(input: TokenStream) -> TokenStream {
         syn::Data::Struct(s) => match s.fields {
             syn::Fields::Named(FieldsNamed { named, .. }) => {
                 let idents_enum = named.iter().map(|f| &f.ident);
-                let idents2_getenum = named.iter().map(|f| &f.ident);
+                let idents_getenum = named.iter().map(|f| &f.ident);
                 let tys = named.iter().map(|f| &f.ty).clone();
+                let tys_for_structinfo = named.iter().map(|f| &f.ty).clone();
                 let enumname = format_ident!("{}{}", ident, "FieldEnum");
+                let structinfo = format_ident!("{}{}", ident, "StructInfo");
 
-                let newnamed = named.clone();
                 let mut set_quotes = vec![];
                 let mut get_quotes = vec![];
                 let mut set_tys = vec![];
                 let mut get_tys = vec![];
 
-                for name in newnamed.clone().iter() {
+                let field_idents = named
+                    .iter()
+                    .map(|f| &f.ident);
+
+                for name in named.clone().iter() {
                     if get_tys.contains(&name.ty) {
                     } else {
                         get_tys.push(name.ty.clone());
                         set_tys.push(name.ty.clone());
-                        let get_filtered_ident = newnamed
+                        let get_filtered_ident = named
                             .iter()
                             .filter(|x| x.ty == name.ty)
                             .map(|f| &f.ident);
-                        let set_filtered_ident = newnamed
+                        let set_filtered_ident = named
                             .iter()
                             .filter(|x| x.ty == name.ty)
                             .map(|f| &f.ident);
@@ -51,6 +56,13 @@ pub fn get(input: TokenStream) -> TokenStream {
                 }
                 quote! {
 
+                    #[derive(Debug)]
+                    struct #structinfo {
+                        field_names: Vec<String>,
+                        field_types: Vec<String>,
+                        struct_name: String
+                    }
+
                     #[derive(Debug, PartialEq, PartialOrd, Clone)]
                     enum #enumname{
                         #(#idents_enum(#tys)),*
@@ -79,12 +91,19 @@ pub fn get(input: TokenStream) -> TokenStream {
                     impl #ident {
                         fn getenum(&mut self, field_string: &String) -> Result<#enumname, String> {
                             match &**field_string {
-                                #(stringify!(#idents2_getenum) => {
-                                    Ok(#enumname::#idents2_getenum(self.#idents2_getenum.clone()))
+                                #(stringify!(#idents_getenum) => {
+                                    Ok(#enumname::#idents_getenum(self.#idents_getenum.clone()))
                                 }),*
                                 _ => Err(format!("invalid field name to get '{}'", field_string)),
                             }
                         }
+
+                        fn getstructinfo(&self) -> #structinfo {
+                            #structinfo {
+                                field_names: vec![#(stringify!(#field_idents).to_string()),*],
+                                field_types: vec![#(stringify!(#tys_for_structinfo).to_string()),*],
+                                struct_name: stringify!(#ident).to_string()}
+                        }
                     }
                 }
             }
